@@ -10,6 +10,11 @@ from subprocess import run as run_process
 from django.core.management.utils import get_random_secret_key
 
 import click
+import rich_click
+
+
+click.Command.format_help = rich_click.rich_format_help
+click.Group.format_help = rich_click.rich_format_help
 
 
 DEFAULT_APP = """#!/usr/bin/env python
@@ -110,12 +115,17 @@ def play(port):
 @click.option(
     "--threads", type=int, help="Number of threads to use when generating static files"
 )
-def record(force, threads):
+@click.option("--output", help="Output directory")
+def record(force, threads, output):
     args = []
 
     if force:
         args.append("--force")
 
+    if output:
+        args.append("--output")
+        args.append(output)
+
     if threads:
         args.append("--threads")
         args.append(str(threads))
